import { defineNuxtModule } from '@nuxt/kit'

export default defineNuxtModule({
  setup(options, nuxt) {
    /**
     * remove default middleware so our works on dev as well
     */
    nuxt.options.serverMiddleware = nuxt.options.serverMiddleware.filter((mw) => !mw.path.includes('sitemap.xml'))

    /**
     * Use addServerHandler to dynamicly add server middlewares in Nuxt 3
     */
    // addServerHandler({
    //   handler: '/path/to/handler',
    // })

    /**
     * pass routes to nitro runtime config
     */
    nuxt.hook('nitro:build:before', (nitro) => {
      nitro.options.runtimeConfig.sitemap = nuxt.options.runtimeConfig.sitemap
    })

    /**
     * Get all static routes and remove dynamic ones
     */
    nuxt.hook('pages:extend', (routes) => {
      nuxt.options.sitemap.staticRoutes = routes
        .map((r) => r.path)
        .filter((path) => ![':', '*'].some((c) => path.includes(c)))
      nuxt.options.runtimeConfig.sitemap = nuxt.options.sitemap
    })
  },
})